| assess_fair | R Documentation |
Resolves a persistent identifier or URL, harvests its metadata, and scores it against the FAIRsFAIR metrics, entirely in R.
assess_fair(
id,
metric_version = "0.8",
use_datacite = TRUE,
metadata_service_endpoint = NULL,
metadata_service_type = metadata_service_types(),
test_debug = FALSE,
resolve = TRUE,
timeout = 15,
use_headless = FALSE
)
id |
A persistent identifier or URL (DOI, Handle, ARK, URN, ...). |
metric_version |
Metric version to use (see |
use_datacite |
Whether to query DataCite for registry metadata. |
metadata_service_endpoint |
Optional URL of an additional metadata
document to harvest, or a ready protocol query URL (for example an OAI-PMH
|
metadata_service_type |
Type hint for |
test_debug |
If |
resolve |
If |
timeout |
Per-request timeout in seconds. |
use_headless |
If |
A fair_assessment object.
a <- assess_fair("https://doi.org/10.5281/zenodo.8347772")
summary(a)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.